<?php
/*
 * Plugin Name: Options for Twenty Twenty Premium
 * Version: 1.2.2
 * Plugin URI: https://webd.uk/options-for-twenty-twenty/
 * Description: Adds even more options to modify the default Wordpress theme Twenty Twenty
 * Author: webd.uk
 * Author URI: https://webd.uk
 */



if (!defined('ABSPATH')) {
    exit('This isn\'t the page you\'re looking for. Move along, move along.');
}



if (!class_exists('options_for_twenty_twenty_premium_class')) {

	class options_for_twenty_twenty_premium_class {

        public static $version = '1.2.2';

		function __construct() {

            add_action('customize_register', array($this, 'oftt_customize_register'), 999);
            add_action('wp_head' , array($this, 'oftt_header_output'));
            add_action('load-post.php', array($this, 'oftt_theme_options_metabox_setup'));
            add_action('load-post-new.php', array($this, 'oftt_theme_options_metabox_setup'));
            add_action('widgets_init', array($this, 'oftt_widgets_init'), 11);

            if (is_admin()) {

                add_filter('pre_set_site_transient_update_plugins', 'ofttPremium::check_plugin_update');
                add_filter('plugins_api', 'ofttPremium::get_plugin_information', 10, 3);
                add_filter('after_plugin_row_' . plugin_basename(__FILE__), 'ofttPremium::activate_purchase_js', 10, 3);
                add_action('wp_ajax_oftt_activate_purchase', 'ofttPremium::activate_purchase');
                add_action('admin_notices', 'ofttPremium::upgrade_notice');
                add_filter('upgrader_pre_download', 'ofttPremium::upgrader_pre_download', 10, 3);
                add_filter('plugin_action_links_' . plugin_basename(__FILE__), array($this, 'oftt_add_plugin_action_links'));

            } else {

                add_action('wp_enqueue_scripts', array($this, 'oftt_enqueue_scripts'));

            }

		}

		function oftt_add_plugin_action_links($links) {

			$settings_links = ofttCommon::plugin_action_links(admin_url('customize.php'), true);

			return array_merge($settings_links, $links);

		}

        function oftt_customize_register($wp_customize) {

            if (!class_exists('reset_customizer_class')) {

                $wp_customize->add_section('reset_customizer', array(
                    'title'     => __('Backup Customizer', 'reset-customizer'),
                    'description'  => __('Reset Customizer plugin allows you to backup and restore your customizer settings. You can also reset the options within each section of the customizer to their defaults without affecting other settings.', 'options-for-twenty-twenty'),
                    'priority'     => 0
                ));

                ofttCommon::add_hidden_control($wp_customize, 'install_reset_customizer', 'reset_customizer', '', sprintf(wp_kses(__('<a href="%s" class="button-primary">Install Reset Customizer plugin</a>.', 'options-for-twenty-twenty'), array('a' => array('href' => array(), 'class' => array()))), esc_url(wp_nonce_url(add_query_arg(array('action' => 'install-plugin', 'plugin' => 'reset-customizer'), self_admin_url('update.php')), 'install-plugin_reset-customizer'))));

            }



            $upgrade_link = '<a href="' . ofttCommon::upgrade_link() . '" title="' . __('Upgrade to Options for Twenty Twenty Premium', 'options-for-twenty-twenty') . '">' . __('Upgrade to Options for Twenty Twenty Premium', 'options-for-twenty-twenty') . '</a>';
            $upgrade_nag = $upgrade_link . __(' to activate this option.', 'options-for-twenty-twenty');



            $control_label = __('True Parallax Background Image', 'options-for-twenty-twenty');
            $control_description = __('Turn on "true parallax" scrolling for the background image.', 'options-for-twenty-twenty');

if (ofttPremium::request_permission()) {

            $wp_customize->add_setting('true_parallax_background_image', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => 'ofttCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('true_parallax_background_image', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_general',
                'settings'      => 'true_parallax_background_image',
                'type'          => 'checkbox'
            ));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'true_parallax_background_image', 'oftt_general', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Inject Sidebar', 'options-for-twenty-twenty');
            $control_description = __('Inject a sidebar into the theme by choosing where you want it shown.', 'options-for-twenty-twenty');

if (ofttPremium::request_permission() == true) {

            $sidebar_locations = array(
                'all' => __('Everywhere', 'options-for-twenty-twenty'),
                'front_page' => __('Front Page', 'options-for-twenty-twenty'),
                'home' => __('Main Blog Page', 'options-for-twenty-twenty'),
                'single' => __('Single Posts', 'options-for-twenty-twenty'),
                'archive' => __('Archive Pages', 'options-for-twenty-twenty')
            );

            foreach(get_post_types(array('public' => 'true')) as $post_type) {

                $post_type_object = get_post_type_object($post_type);
                $sidebar_locations['post_type/' . $post_type] = __('Post Type: ', 'options-for-twenty-twenty') . $post_type_object->label;

                foreach (get_object_taxonomies($post_type, 'objects') as $taxonomy) {

                    $sidebar_locations['taxonomy/' . $post_type . '/' . $taxonomy->name] = $post_type_object->label . __(' Taxonomy: ', 'options-for-twenty-twenty') . $taxonomy->label;

                }

            }

            $wp_customize->add_setting('inject_sidebar', array(
                'default'       => array(
				    'author',
				    'post-date',
				    'comments',
				    'sticky'
				),
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttCommon::sanitize_multiple_options'
            ));
            $wp_customize->add_control(new webd_Customize_Control_Checkbox_Multiple($wp_customize, 'inject_sidebar', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_general',
                'settings'      => 'inject_sidebar',
                'choices'       => $sidebar_locations
            )));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'inject_sidebar', 'oftt_general', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Sidebar Width', 'options-for-twenty-twenty');
            $control_description = __('Set the width of the injected sidebar.', 'options-for-twenty-twenty');

if (ofttPremium::request_permission() == true) {

            $wp_customize->add_setting('sidebar_width', array(
                'default'           => 33,
                'transport'         => 'refresh',
                'sanitize_callback' => 'absint'
            ));
            $wp_customize->add_control('sidebar_width', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_general',
                'settings'      => 'sidebar_width',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 20,
                    'max'   => 80,
                    'step'  => 1
                ),
            ));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'sidebar_width', 'oftt_general', $control_label, $control_description . ' ' . $upgrade_nag);

}

            if (get_theme_mod('toggle_use_dashicon')) {

                if (!get_theme_mod('nav_toggle_dashicon')) {

                    set_theme_mod('nav_toggle_dashicon', 'menu');

                }

                remove_theme_mod('toggle_use_dashicon');

            }

            if (file_exists(ABSPATH . WPINC . '/css/dashicons.css')) {

                $dashicons_css = explode("\n", implode('', file(ABSPATH . WPINC . '/css/dashicons.css')));
                $dashicons = array();

                foreach ($dashicons_css as $css_entry) {

                    if (strlen($css_entry) > 10 && substr($css_entry, 0, 11) === '.dashicons-') {

                        $dashicon_class = sanitize_key(preg_replace(array('/^.dashicons-/', '/:before {$/'), '', $css_entry));
                        $dashicons[$dashicon_class] = __(ucwords(str_replace('-', ' ', $dashicon_class)), 'options-for-twenty-twenty');

                    }

                }

                asort($dashicons);

                $dashicons =  array(
                    '' => __('Default (...)')
                ) + $dashicons;

                $control_label = __('Custom Toggle Dashicon', 'options-for-twenty-twenty');
                $control_description = sprintf(wp_kses(__('Choose your own <a href="%s">dashicon</a> for the button that opens the expanded / mobile menu.', 'options-for-twenty-twenty'), array('a' => array('href' => array()))), esc_url('https://developer.wordpress.org/resource/dashicons/'));

                if (ofttPremium::request_permission()) {

                    $wp_customize->remove_control('toggle_use_dashicon');

                    $wp_customize->add_setting('nav_toggle_dashicon', array(
                        'default'       => '',
                        'type'          => 'theme_mod',
                        'transport'     => 'refresh',
                        'sanitize_callback' => 'ofttCommon::sanitize_options'
                    ));
                    $wp_customize->add_control('nav_toggle_dashicon', array(
                        'label'         => $control_label,
                        'description'   => $control_description,
                        'section'       => 'oftt_navigation',
                        'settings'      => 'nav_toggle_dashicon',
                        'type'          => 'select',
                        'choices'       => $dashicons
                    ));

                } else {

                    ofttCommon::add_hidden_control($wp_customize, 'nav_toggle_dashicon', 'oftt_navigation', $label = $control_label, $control_description . ' ' . $upgrade_nag);

                }

            }

            $control_label = __('Animate Close Menu Icon', 'options-for-twenty-twenty');
            $control_description = __('Animate the close menu toggle on the expanded menu.', 'options-for-twenty-twenty');

if (ofttPremium::request_permission() == true) {

            $wp_customize->add_setting('animate_close_toggle', array(
                'default'       => false,
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('animate_close_toggle', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_navigation',
                'settings'      => 'animate_close_toggle',
                'type'          => 'checkbox'
            ));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'animate_close_toggle', 'oftt_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Sticky Desktop Menu', 'options-for-twenty-twenty');
            $control_description = __('Fix the site navigation to the top of the page on large screens.', 'options-for-twenty-twenty');

if (ofttPremium::request_permission() == true) {

            $wp_customize->add_setting('sticky_desktop_menu', array(
                'default'       => '',
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttCommon::sanitize_options'
            ));
            $wp_customize->add_control('sticky_desktop_menu', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_navigation',
                'settings'      => 'sticky_desktop_menu',
                'type'          => 'select',
                'choices'       => array(
                    '' => __('Off', 'options-for-twenty-twenty'),
                    'bar' => __('Sticky Menu Bar', 'options-for-twenty-twenty'),
                    'button' => __('Sticky Expanded Menu Button', 'options-for-twenty-twenty'),
                    'hidden' => __('Sticky Button (Hidden in Bar)', 'options-for-twenty-twenty')
                )
            ));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'sticky_desktop_menu', 'oftt_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Sticky Mobile Menu', 'options-for-twenty-twenty');
            $control_description = __('Fix the site navigation to the top right on scroll down on small screens.', 'options-for-twenty-twenty');

if (ofttPremium::request_permission() == true) {

            $wp_customize->add_setting('sticky_mobile_menu', array(
                'default'       => '',
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttCommon::sanitize_options'
            ));
            $wp_customize->add_control('sticky_mobile_menu', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_navigation',
                'settings'      => 'sticky_mobile_menu',
                'type'          => 'select',
                'choices'       => array(
                    '' => __('Off', 'options-for-twenty-twenty'),
                    'bar' => __('Sticky Menu Bar', 'options-for-twenty-twenty'),
                    'button' => __('Sticky Menu Button', 'options-for-twenty-twenty')
                )
            ));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'sticky_mobile_menu', 'oftt_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Menu Button Background Color', 'options-for-twenty-twenty');
            $control_description = __('Set the background color of the sticky menu button.', 'options-for-twenty-twenty');

if (ofttPremium::request_permission() == true) {

            $wp_customize->add_setting('menu_button_background_color', array(
                'default'       => '',
                'transport'     => 'refresh',
                'sanitize_callback' => 'sanitize_hex_color'
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'menu_button_background_color', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_navigation',
            	'settings'      => 'menu_button_background_color'
            )));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'menu_button_background_color', 'oftt_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Sticky Menu Dropshadow', 'options-for-twenty-twenty');
            $control_description = __('Add a dropshadow to the sticky menus.', 'options-for-twenty-twenty');

if (ofttPremium::request_permission() == true) {

            $wp_customize->add_setting('sticky_menu_dropshadow', array(
                'default'       => false,
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('sticky_menu_dropshadow', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_navigation',
                'settings'      => 'sticky_menu_dropshadow',
                'type'          => 'checkbox'
            ));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'sticky_menu_dropshadow', 'oftt_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Animate Dropshadow', 'options-for-twenty-twenty');
            $control_description = __('Give a 3D animation to the dropshadow on sticky menus.', 'options-for-twenty-twenty');

if (ofttPremium::request_permission() == true) {

            $wp_customize->add_setting('sticky_menu_shadow_animate', array(
                'default'       => false,
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('sticky_menu_shadow_animate', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_navigation',
                'settings'      => 'sticky_menu_shadow_animate',
                'type'          => 'checkbox'
            ));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'sticky_menu_shadow_animate', 'oftt_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Footer Order', 'options-for-twenty-twenty');
            $control_description = __('Order the sections in the site\'s footer.', 'options-for-twenty-twenty');

if (ofttPremium::request_permission() == true) {

            $wp_customize->add_setting('footer_order', array(
                'default'       => '',
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttCommon::sanitize_options'
            ));
            $wp_customize->add_control('footer_order', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_footer',
                'settings'      => 'footer_order',
                'type'          => 'select',
                'choices'       => array(
                    '' => __('Menu -> Widgets -> Copyright', 'options-for-twenty-twenty'),
                    '021' => __('Menu -> Copyright -> Widgets', 'options-for-twenty-twenty'),
                    '120' => __('Widgets -> Copyright -> Menu', 'options-for-twenty-twenty'),
                    '102' => __('Widgets -> Menu -> Copyright', 'options-for-twenty-twenty'),
                    '210' => __('Copyright -> Widgets -> Menu', 'options-for-twenty-twenty'),
                    '201' => __('Copyright -> Menu -> Widgets', 'options-for-twenty-twenty')
                )
            ));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'footer_order', 'oftt_footer', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Footer Sidebars', 'options-for-twenty-twenty');
            $control_description = __('Add a third or fourth widget ready sidebar to the footer area of the theme.', 'options-for-twenty-twenty');

if (ofttPremium::request_permission() == true) {

            $wp_customize->add_setting('footer_sidebars', array(
                'default'       => '',
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttCommon::sanitize_options'
            ));
            $wp_customize->add_control('footer_sidebars', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_footer',
                'settings'      => 'footer_sidebars',
                'type'          => 'select',
                'choices'       => array(
                    '1' => __('1 Footer Sidebar', 'options-for-twenty-twenty'),
                    '' => __('2 Footer Sidebars', 'options-for-twenty-twenty'),
                    '3' => __('3 Footer Sidebars', 'options-for-twenty-twenty'),
                    '4' => __('4 Footer Sidebars', 'options-for-twenty-twenty')
                )
            ));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'footer_sidebars', 'oftt_footer', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Replace "Powered by" Text', 'options-for-twenty-twenty');
            $control_description = __('Provide alternate text to replace "Proudly powered by Wordpress".', 'options-for-twenty-twenty');

if (ofttPremium::request_permission() == true) {

            $wp_customize->add_setting('replace_powered_by_wordpress', array(
                'default'           => '',
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => 'wp_kses_post'
            ));
            $wp_customize->add_control('replace_powered_by_wordpress', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_footer',
                'settings'      => 'replace_powered_by_wordpress',
                'type'          => 'text'
            ));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'replace_powered_by_wordpress', 'oftt_footer', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Enable Privacy Link', 'options-for-twenty-twenty');
            $control_description = sprintf(wp_kses(__('Injects link to the privacy policy page set in <a href="%s">Privacy Settings</a>.', 'options-for-twenty-twenty'), array('a' => array('href' => array()))), esc_url(admin_url('options-privacy.php')));

if (ofttPremium::request_permission() == true) {

            $wp_customize->add_setting('privacy_link', array(
                'default'           => false,
                'transport'         => 'refresh',
                'sanitize_callback' => 'wp_kses_post'
            ));
            $wp_customize->add_control('privacy_link', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_footer',
                'settings'      => 'privacy_link',
                'type'          => 'checkbox'
            ));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'privacy_link', 'oftt_footer', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Background Slider', 'options-for-twenty-twenty');
            $control_description = sprintf(
                wp_kses(__('Places a <a href="%s">MetaSlider</a> slider in the background of the Cover Template.', 'options-for-twenty-twenty'), array('a' => array('href' => array()))),
                esc_url(add_query_arg( array(
                    's' => 'ml-slider',
                    'tab' => 'search',
                    'type' => 'term'
                ), admin_url('plugin-install.php')))
            );

if (ofttPremium::request_permission()) {

            $wp_customize->add_setting('slider_cover', array(
                'default'       => '',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttCommon::sanitize_options'
            ));
            $installed_sliders = array();

            if (class_exists('MetaSliderPlugin')) {

                $installed_sliders[] = 'ml-slider';

            }

            $sliders_array = array('' => 'No slider');

            if (!empty($installed_sliders)) {

                $available_sliders = get_posts(array(
                    'post_type' => $installed_sliders,
                    'posts_per_page' => -1,
                ));

                foreach ($available_sliders as $available_slider) {

                    $sliders_array[$available_slider->ID] = $available_slider->post_title;

                }

            }

            $wp_customize->add_control('slider_cover', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'cover_template_options',
                'settings'      => 'slider_cover',
                'type'          => 'select',
                'choices'       => $sliders_array
            ));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'slider_cover', 'cover_template_options', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $wp_customize->remove_control('expanded_menu_widgets_1');
            $wp_customize->remove_control('expanded_menu_widgets_2');
            $wp_customize->remove_control('mobile_menu_widgets_1');
            $wp_customize->remove_control('mobile_menu_widgets_2');

        }

        function oftt_header_output() {

            global $post;

?>
<!--Customizer CSS-->
<style type="text/css">
.modal-menu .widget {
    border-top: 1px solid #dbdbdb;
    padding: 2.5rem 0;
}
.modal-menu .widget a {
    display: inline;
    padding: 0;
}
<?php

if (ofttPremium::request_permission() == true) {

            if (get_theme_mod('true_parallax_background_image')) {

                add_action('get_footer', array($this, 'oftt_inject_background_image_true_parallax'));

            }

            if (get_theme_mod('inject_sidebar') || ((is_single() || is_page()) && get_post_meta(get_the_ID(), 'oftt_show_sidebar', true) == '1')) {

                add_filter('wp_footer', array($this, 'oftt_inject_sidebar'));

?>
@media (min-width: 700px) {
    #site-content-wrapper {
        display: flex;
    }
<?php

                $mod = get_theme_mod('sidebar_width');

                if ($mod) {
?>
    #site-content-wrapper>#site-content {
        width: <?= 100 - absint($mod); ?>%;
    }
    #site-content-wrapper>#sidebar {
        width: <?= absint($mod); ?>%;
    }  
<?php
                } else {

?>
    #site-content-wrapper>#site-content {
        width: 67%;
    }
    #site-content-wrapper>#sidebar {
        width: 33%;
    }  
<?php

                }

?>
}
#site-content-wrapper {
    margin: 0 auto;
}
<?php

                $mod = get_theme_mod('content_width');

                if ($mod) {

                    ofttCommon::generate_css('#site-content-wrapper', 'max-width', 'content_width');

                } else {

?>
#site-content-wrapper {
    max-width: 58rem;
}
<?php

                }

            }

            if (get_theme_mod('toggle_use_dashicon') || get_theme_mod('nav_toggle_dashicon')) {

                global $options_for_twenty_twenty_object;

                remove_action('wp_footer', array($options_for_twenty_twenty_object, 'oftt_toggle_use_dashicon'));
                add_action('wp_footer', array($this, 'oftt_toggle_use_dashicon'));

?>
.nav-toggle .toggle-icon {
    height: auto;
}
.nav-toggle .toggle-inner {
    padding-top: 0.2rem;
}
.nav-toggle .toggle-inner .dashicons, .dashicons-before:before {
    width: 23px;
    height: 23px;
    font-size: 23px;
}
<?php

            }

            if (get_theme_mod('animate_close_toggle')) {

?>
button.close-nav-toggle svg {
    transition: transform .2s ease-in-out;
}
button.close-nav-toggle:hover svg {
    transform: rotate(180deg);
}
<?php

            }

            add_filter('wp_nav_menu', array($this, 'oftt_menu_widgets'), 10, 2);

            if ((is_page() || is_single()) && get_post_meta(get_the_ID(), 'oftt_hide_header', true) == '1') {

                if (get_theme_mod('hide_all_headers')) { $show_or_hide = 'block'; } else { $show_or_hide = 'none'; }

?>
header.entry-header {
    display: <?= $show_or_hide; ?>;
}
<?php

            }

            if ((is_page() || is_single()) && get_post_meta(get_the_ID(), 'oftt_hide_header_title', true) == '1') {

                if (get_theme_mod('hide_all_header_titles')) { $show_or_hide = 'visible'; } else { $show_or_hide = 'hidden'; }

?>
header.entry-header h1.entry-title {
    visibility: <?= $show_or_hide; ?>;
}
<?php

            }

            if ((is_page() || is_single()) && get_post_meta(get_the_ID(), 'oftt_hide_featured_image', true) == '1') {

                if (get_theme_mod('hide_all_featured_images')) { $show_or_hide = 'block'; } else { $show_or_hide = 'none'; }

?>
.featured-media {
    display: <?= $show_or_hide; ?>;
}
<?php

            }

            if (get_theme_mod('sticky_mobile_menu') || get_theme_mod('sticky_desktop_menu')) {

                add_action('wp_footer', array($this, 'oftt_sticky_menu'));

            }

            if (get_theme_mod('sticky_mobile_menu') == 'button') {

?>
@media (max-width: 1000px) {
<?php

                if (get_theme_mod('menu_button_background_color')) {

?>
    #site-header .sticky {
        background-color: <?= get_theme_mod('menu_button_background_color'); ?>;
    }
<?php

                } else {

?>
    #site-header div:not(.search-modal, .search-modal-inner), #site-header .sticky {
        background-color: inherit;
    }
<?php

                }

?>
	#site-header .sticky {
        position: fixed;
        z-index: 1;
		top: 1rem;
		right: 1rem;
		bottom: auto;
		height: 6.6rem;
		border-radius: 100%;
    }<?php if (!get_theme_mod('hide_toggle_text')) { ?>
	#site-header .sticky .toggle-inner {
		margin-top: -1.5rem;
	}<?php } ?>
	#site-header .sticky .toggle-inner .toggle-text {
        top: 100%
	}
    .admin-bar #site-header .sticky {
		top: calc(1rem + 32px);
    }
}
@media (max-width: 600px) {
    .admin-bar #site-header .sticky {
		top: calc(1rem);
    }
}
@media (max-width: 782px) {
    .admin-bar #site-header .sticky {
		top: calc(1rem + 46px);
    }
}
@media (max-width: 600px) {
    .admin-bar #site-header .sticky {
		top: 1rem;
    }
}
<?php

            }

            if (get_theme_mod('sticky_desktop_menu') == 'button' || get_theme_mod('sticky_desktop_menu') == 'hidden') {

?>
@media (min-width: 1000px) {
<?php

                if (get_theme_mod('sticky_desktop_menu') == 'hidden') {

?>
    #site-header .desktop-nav-toggle:not(.sticky) {
        position: absolute;
        right: -100vh;
    }
    .header-footer-group table caption, body:not(.overlay-header) .header-inner .toggle-wrapper::before {
        background: none;
    }
<?php

                }

                if (get_theme_mod('menu_button_background_color')) {

?>
    #site-header .sticky {
        background-color: <?= get_theme_mod('menu_button_background_color'); ?>;
    }
<?php

                } else {

?>
    #site-header div:not(.search-modal, .search-modal-inner), #site-header .sticky {
        background-color: inherit;
    }
<?php

                }

?>
	#site-header .sticky {
        position: fixed;
        z-index: 1;
		top: 1rem;
		right: 1rem;
		bottom: auto;
		height: 6.6rem;
		border-radius: 100%;
		padding: 0 1.8rem 0 2.2rem;
    }<?php if (!get_theme_mod('hide_toggle_text')) { ?>
	#site-header .sticky .toggle-inner {
		margin-top: -1.5rem;
	}<?php } ?>
	#site-header .sticky .toggle-inner .toggle-text {
        top: 50%
	}
    .admin-bar #site-header .sticky {
		top: calc(1rem + 32px);
    }
}
@media (max-width: 782px) {
    .admin-bar #site-header .sticky {
		top: calc(1rem + 46px);
    }
}
@media (max-width: 600px) {
    .admin-bar #site-header .sticky {
		top: 1rem;
    }
}
<?php

            }

            if (get_theme_mod('sticky_mobile_menu') == 'bar') {

?>
@media (max-width: 1000px) {
    #site-header, .overlay-header #site-header {
        position: fixed;
        top: 0;
        right: 0;
        left: 0;
        z-index: 2;
    }
}
.admin-bar #site-header {
    top: 0;
}
@media screen and (min-width: 601px) {
    .admin-bar #site-header {
        top: 46px;
    }
}
@media screen and (min-width: 783px) {
    .admin-bar #site-header {
        top: 32px;
    }
}
@media screen and (min-width: 1000px) {
    .admin-bar #site-header {
        top: 0;
    }
}
<?php

            }

            if (get_theme_mod('sticky_desktop_menu') == 'bar') {

?>
@media (min-width: 1000px) {
    #site-header, .overlay-header #site-header {
        position: fixed;
        top: 0;
        right: 0;
        left: 0;
        z-index: 2;
    }
    .admin-bar #site-header {
        top: 32px;
    }
}
<?php

            }

            if (get_theme_mod('sticky_menu_dropshadow') && get_theme_mod('sticky_mobile_menu') == 'bar') {

                if (get_theme_mod('sticky_menu_shadow_animate')) {

?>
@media (max-width: 1000px) {
    #site-header {
        transition: box-shadow 0.3s ease-in-out;
    }
    #site-header.shadow {
        box-shadow: 0px 4px 17px 4px rgba(0,0,0,0.3);
    }
}
<?php

                } else {

?>
@media (max-width: 1000px) {
    #site-header {
        box-shadow: 0px 4px 17px 4px rgba(0,0,0,0.3);
    }
}
<?php

                }

            }

            if (get_theme_mod('sticky_menu_dropshadow') && get_theme_mod('sticky_desktop_menu') == 'bar') {

                if (get_theme_mod('sticky_menu_shadow_animate')) {

?>
@media (min-width: 1000px) {
    #site-header {
        transition: box-shadow 0.6s ease-in-out;
    }
    #site-header.shadow {
        box-shadow: 0px 4px 17px 4px rgba(0,0,0,0.3);
    }
}
<?php

                } else {

?>
@media (min-width: 1000px) {
    #site-header {
        box-shadow: 0px 4px 17px 4px rgba(0,0,0,0.3);
    }
}
<?php

                }

            }

            if (get_theme_mod('sticky_menu_dropshadow')) {

?>
#site-header .sticky {
<?php

                if (get_theme_mod('sticky_menu_shadow_animate')) {

?>
    transform: scale(0.8, 0.8);
    transition: box-shadow 0.3s ease-in-out, transform 0.3s ease-in-out;
    border: 1px solid rgba(0,0,0,0.1);
}
#site-header .shadow {
    box-shadow: 0px 4px 17px 4px rgba(0,0,0,0.3);
    transform: scale(1, 1);
}
#site-header .sticky:hover {
    transform: scale(1, 1);
<?php

                }

?>
    box-shadow: 0px 4px 17px 4px rgba(0,0,0,0.3);
}
<?php

            }

            if (get_theme_mod('footer_order')) {

                add_action('wp_footer', array($this, 'oftt_footer_order'));

?>
#site-content {
	margin-bottom: 8rem;
}
#site-footer {
	margin-top: 0;
	border-top: 0.1rem solid #dcd7ca;
}
.reduced-spacing.footer-top-visible .footer-nav-widgets-wrapper {
	margin-top: 0;
}
.footer-widgets-outer-wrapper, .footer-top {
	border-bottom: none;
}
<?php

            }

            if (get_theme_mod('footer_sidebars')) {

                add_action('dynamic_sidebar_after', array($this, 'oftt_get_footer_sidebars'), 10, 2);

                if (get_theme_mod('footer_sidebars') == 1) {

?>
@media (min-width: 700px) {
    .footer-widgets {
        width: auto;
    }
}
@media (min-width: 1220px) {
    .footer-widgets-wrapper {
        margin-left: 0;
        width: auto;
    }
}
<?php

                } elseif (get_theme_mod('footer_sidebars') == 3) {

?>
@media (min-width: 700px) {
    .footer-widgets {
        width: 33.3333333333%
    }
}
<?php

                } elseif (get_theme_mod('footer_sidebars') == 4) {

?>
@media (min-width: 700px) {
    .footer-widgets {
        width: 25%
    }
}
<?php

                }

            }

            if (get_theme_mod('replace_powered_by_wordpress')) {

                add_action('wp_footer', array($this, 'oftt_replace_powered_by_wordpress'));

            }

            if (get_theme_mod('privacy_link')) {

                add_action('wp_footer', array($this, 'oftt_privacy_link'));

?>
.footer-privacy {
    margin: 0 0 0 2.4rem;
}
<?php

            }

            if (get_theme_mod('slider_cover') || (is_page() && get_post_meta(get_the_ID(), 'oftt_cover_slider', true))) {

                add_action('get_template_part_template-parts/content-cover', array($this, 'oftt_inject_slider_cover'), 10, 2);

?>
.cover-slider>.metaslider.ml-slider {
    position: absolute;
    height: 100vh;
    overflow: hidden;
}
.cover-slider>.metaslider.ml-slider .slides img, .cover-slider>.metaslider.ml-slider img {
    height: 100vh !important;
    object-fit: cover;
}
.admin-bar .cover-slider>.metaslider.ml-slider, .admin-bar .cover-slider>.metaslider.ml-slider .slides img, .admin-bar  .cover-slider>.metaslider.ml-slider img {
	height: calc(100vh - 32px) !important;
}
@media (max-width: 600px) {
    .admin-bar .cover-slider>.metaslider.ml-slider, .admin-bar .cover-slider>.metaslider.ml-slider .slides img, .admin-bar  .cover-slider>.metaslider.ml-slider img {
		height: 100vh !important;
    }
}
@media (max-width: 782px) {
    .admin-bar .cover-slider>.metaslider.ml-slider, .admin-bar .cover-slider>.metaslider.ml-slider .slides img, .admin-bar  .cover-slider>.metaslider.ml-slider img {
		height: calc(100vh - 46px) !important;
    }
}
<?php

            }

}

?>
</style> 
<!--/Customizer CSS-->
<?php

        }

        function oftt_inject_background_image_true_parallax() {

            if (set_url_scheme(get_background_image())) {

?>
<script type="text/javascript">
    document.body.style.backgroundSize = 'auto 300vh';
	document.body.style.backgroundPosition = '50% -' + Math.round(((2 * window.innerHeight) * window.scrollY) / (document.body.clientHeight - window.innerHeight)) +  'px';
    window.addEventListener('scroll', function() {
    	if (window.matchMedia('(min-width: 1000px)').matches) {
    		document.body.style.backgroundPosition = '50% -' + Math.round(((2 * window.innerHeight) * window.scrollY) / (document.body.clientHeight - window.innerHeight)) +  'px';
        }
    });
</script>
<?php

            }

        }

        function oftt_inject_sidebar() {

            $inject_sidebar_args = get_theme_mod('inject_sidebar');

            if (is_archive()) {

                global $wp_query;
                $taxonomy = $wp_query->get_queried_object();

            }

            if (
                is_active_sidebar('sidebar') && (
                    in_array('all', $inject_sidebar_args) ||
                    (in_array('front_page', $inject_sidebar_args) && is_front_page()) ||
                    (in_array('home', $inject_sidebar_args) && is_home()) ||
                    (in_array('single', $inject_sidebar_args) && is_single()) ||
                    (in_array('archive', $inject_sidebar_args) && is_archive()) ||
                    (is_single() && in_array('post_type/' . get_post_type() , $inject_sidebar_args)) ||
                    (is_page() && !is_front_page() && in_array('post_type/page', $inject_sidebar_args)) ||
                    (is_archive() && in_array('taxonomy/' . get_post_type() . '/' . $taxonomy->taxonomy , $inject_sidebar_args)) ||
                    ((is_single() || is_page()) && get_post_meta(get_the_ID(), 'oftt_show_sidebar', true) == '1')
                )
            ) {

?>
<aside id="sidebar" class="widget-area" role="complementary" aria-label="<?php esc_attr_e( 'Sidebar', 'options-for-twenty-twenty' ); ?>">
<?php dynamic_sidebar('sidebar'); ?>
</aside>
<script type="text/javascript">
    (function () {
        var wrapper = document.createElement('div'),
            content,
            sidebar = document.getElementById('sidebar');
        content = <?php if (is_single() or is_page()) { ?>document.getElementsByClassName('post-inner')[0];<?php } else { ?>document.getElementById('site-content');<?php } ?>
        wrapper.id = 'site-content-wrapper';
        content.parentNode.insertBefore(wrapper, content);
        wrapper.appendChild(content);
        wrapper.appendChild(sidebar);
    }());
</script>
<?php

            }

        }

        function oftt_toggle_use_dashicon() {

            if (!get_theme_mod('nav_toggle_dashicon') && get_theme_mod('toggle_use_dashicon') == 1) {

                set_theme_mod('nav_toggle_dashicon', 'menu');
                remove_theme_mod('toggle_use_dashicon');

            }

?>
<script type="text/javascript">
    (function () {
        var navToggles = document.querySelectorAll('.nav-toggle .toggle-icon');
            Array.prototype.forEach.call(navToggles, function(navToggle) {
            navToggle.innerHTML = '<span alt="Menu" class="dashicons dashicons-dashicons dashicons-<?= get_theme_mod('nav_toggle_dashicon'); ?>"></span>';
        });
    }());
</script>
<?php

        }

        function oftt_enqueue_scripts() {

            if (get_theme_mod('nav_toggle_dashicon')) {

                wp_enqueue_style('dashicons');

            }

        }

        function oftt_menu_widgets($nav_menu, $args) {

            if (ofttPremium::request_permission() && isset($args->theme_location) && $args->theme_location == 'expanded') {

		        if (is_active_sidebar('expanded-1')) {

                    $nav_menu = '<div class="expanded-widgets">' . $this->oftt_get_dynamic_sidebar('expanded-1') . '</div>' . $nav_menu;

                }

		        if (is_active_sidebar('expanded-2')) {

                    $nav_menu =  $nav_menu . '<div class="expanded-widgets">' . $this->oftt_get_dynamic_sidebar('expanded-2') . '</div>';

                }

            }

            if (ofttPremium::request_permission() && isset($args->theme_location) && $args->theme_location == 'mobile') {

		        if (is_active_sidebar('mobile-1')) {

                    $nav_menu = '<div class="mobile-widgets">' . $this->oftt_get_dynamic_sidebar('mobile-1') . '</div>' . $nav_menu;

                }

		        if (is_active_sidebar('mobile-2')) {

                    $nav_menu =  $nav_menu . '<div class="mobile-widgets">' . $this->oftt_get_dynamic_sidebar('mobile-2') . '</div>';

                }

            }

            return $nav_menu;

        }

        function oftt_get_dynamic_sidebar($index = 1) {

            $sidebar_contents = '';
            ob_start();
            dynamic_sidebar($index);
            $sidebar_contents = ob_get_clean();

            return $sidebar_contents;

        }

        function oftt_sticky_menu() {

?>
<script type="text/javascript">
    (function () {<?php

        if (get_theme_mod('sticky_mobile_menu') == 'bar' || get_theme_mod('sticky_desktop_menu') == 'bar') {

            if (get_theme_mod('sticky_mobile_menu') == 'bar') { $width_condition = 'document.body.clientWidth < 1000'; }

            if (get_theme_mod('sticky_desktop_menu') == 'bar') { $width_condition = 'document.body.clientWidth >= 1000'; }

            if (get_theme_mod('sticky_mobile_menu') == 'bar' && get_theme_mod('sticky_desktop_menu') == 'bar') { $width_condition = '1 == 1'; }

?>
                if (typeof document.getElementsByClassName('overlay-header')[0] === 'undefined') {
                    var windowResize;
                    (windowResize = function(){
                        document.getElementsByClassName('to-the-top')[0].href = '#site-content';
                        if (<?= $width_condition; ?>) {
                            document.body.style.marginTop = document.getElementById('site-header').clientHeight + 'px';
                        } else {
                            document.body.style.marginTop = 0;
                        }
                    }).call();
                    window.onresize = windowResize;
                }
                window.addEventListener('scroll', function() {
                    var siteHeader = document.getElementById('site-header');
                    if (!siteHeader.classList.contains('shadow')) {
                        siteHeader.classList.add('shadow');
                        setTimeout(function() {
                            siteHeader.classList.remove('shadow');
                        }, 1800);
                    }
                });
<?php

        }

            if (get_theme_mod('sticky_mobile_menu') == 'button' || get_theme_mod('sticky_desktop_menu') == 'button' || get_theme_mod('sticky_desktop_menu') == 'hidden') {

                if (get_theme_mod('sticky_mobile_menu') == 'button') { $width_condition = 'document.body.clientWidth < 1000'; }

                if (get_theme_mod('sticky_desktop_menu') == 'button' || get_theme_mod('sticky_desktop_menu') == 'hidden') { $width_condition = 'document.body.clientWidth >= 1000'; }

                if (get_theme_mod('sticky_mobile_menu') == 'button' && (get_theme_mod('sticky_desktop_menu') == 'button' || get_theme_mod('sticky_desktop_menu') == 'hidden')) { $width_condition = '1 == 1'; }

?>

        window.addEventListener('scroll', function() {
            var navToggles = document.getElementById('site-header').getElementsByClassName('nav-toggle');
            if (<?= $width_condition; ?>) {
                Array.prototype.forEach.call(navToggles, function(navToggle) {
                    var siteHeaderHeight = document.getElementById('site-header').clientHeight;
                    var adminBar = document.getElementById('wpadminbar');
                    if (adminBar !== null && document.body.clientWidth <= 600) { siteHeaderHeight += adminBar.clientHeight; }
                    if ((window.pageYOffset || (document.documentElement || document.body.parentNode || document.body).scrollTop) > siteHeaderHeight) {
                        if (!navToggle.classList.contains('sticky')) {
                            navToggle.classList.add('sticky');
                            if (!navToggle.classList.contains('shadow')) {
                                navToggle.classList.add('shadow');
                                setTimeout(function() {
                                    navToggle.classList.remove('shadow');
                                }, 600);
                            }
                        }
                    } else {
                        if (navToggle.classList.contains('sticky')) {
                            navToggle.classList.remove('sticky');
                        }
                    }
                });
            } else {
                Array.prototype.forEach.call(navToggles, function(navToggle) {
                    if (navToggle.classList.contains('sticky')) {
                        navToggle.classList.remove('sticky');
                    }
                });
            }
        });<?php

            }

?>
    }());
</script>
<?php

        }

        function oftt_widgets_init() {

            if (ofttPremium::request_permission() == true) {

                register_sidebar(array(
                    'name'          => __( 'Sidebar', 'options-for-twenty-twenty' ),
                    'id'            => 'sidebar',
                    'description'   => __( 'Widgets in this area will be displayed in your website\'s sidebar.', 'options-for-twenty-twenty' ),
                    'before_title'  => '<h2 class="widget-title subheading heading-size-3">',
                    'after_title'   => '</h2>',
                    'before_widget' => '<section id="%1$s" class="widget %2$s">',
                    'after_widget'  => '</section>'
		        ));

    	        register_sidebar(array(
				    'name'          => __('Expanded #1', 'options-for-twenty-twenty'),
				    'id'            => 'expanded-1',
				    'description'   => __('Widgets in this area will be displayed above the expanded menu.', 'options-for-twenty-twenty'),
		            'before_title'  => '<h2 class="widget-title subheading heading-size-3">',
		            'after_title'   => '</h2>',
                    'before_widget' => '<div class="widget %2$s"><div class="widget-content">',
		            'after_widget'  => '</div></div>'
                ));

    	        register_sidebar(array(
    			    'name'          => __('Expanded #2', 'options-for-twenty-twenty'),
    			    'id'            => 'expanded-2',
    			    'description'   => __('Widgets in this area will be displayed below the expanded menu.', 'options-for-twenty-twenty'),
    	            'before_title'  => '<h2 class="widget-title subheading heading-size-3">',
    	            'after_title'   => '</h2>',
                    'before_widget' => '<div class="widget %2$s"><div class="widget-content">',
    	            'after_widget'  => '</div></div>'
                ));

    	        register_sidebar(array(
				    'name'          => __('Mobile #1', 'options-for-twenty-twenty'),
				    'id'            => 'mobile-1',
				    'description'   => __('Widgets in this area will be displayed above the mobile menu.', 'options-for-twenty-twenty'),
		            'before_title'  => '<h2 class="widget-title subheading heading-size-3">',
		            'after_title'   => '</h2>',
                    'before_widget' => '<div class="widget %2$s"><div class="widget-content">',
		            'after_widget'  => '</div></div>'
                ));

    	        register_sidebar(array(
    			    'name'          => __('Mobile #2', 'options-for-twenty-twenty'),
    			    'id'            => 'mobile-2',
    			    'description'   => __('Widgets in this area will be displayed below the mobile menu.', 'options-for-twenty-twenty'),
    	            'before_title'  => '<h2 class="widget-title subheading heading-size-3">',
    	            'after_title'   => '</h2>',
                    'before_widget' => '<div class="widget %2$s"><div class="widget-content">',
    	            'after_widget'  => '</div></div>'
                ));

                if (get_theme_mod('footer_sidebars')) {

                    if (get_theme_mod('footer_sidebars') && get_theme_mod('footer_sidebars') == '1') {

            	        unregister_sidebar('sidebar-2');

                    }

                    if (get_theme_mod('footer_sidebars') && (get_theme_mod('footer_sidebars') == '4' || get_theme_mod('footer_sidebars') == '3')) {

            	        register_sidebar(array(
        				    'name'          => __('Footer #3', 'options-for-twenty-twenty'),
        				    'id'            => 'sidebar-3',
        				    'description'   => __('Widgets in this area will be displayed in the third column in the footer.', 'options-for-twenty-twenty'),
        		            'before_title'  => '<h2 class="widget-title subheading heading-size-3">',
        		            'after_title'   => '</h2>',
                            'before_widget' => '<div class="widget %2$s"><div class="widget-content">',
        		            'after_widget'  => '</div></div>'
                        ));

                    }

                    if (get_theme_mod('footer_sidebars') && get_theme_mod('footer_sidebars') == '4') {

            	        register_sidebar(array(
        				    'name'          => __('Footer #4', 'options-for-twenty-twenty'),
        				    'id'            => 'sidebar-4',
        				    'description'   => __('Widgets in this area will be displayed in the fourth column in the footer.', 'options-for-twenty-twenty'),
        		            'before_title'  => '<h2 class="widget-title subheading heading-size-3">',
        		            'after_title'   => '</h2>',
                            'before_widget' => '<div class="widget %2$s"><div class="widget-content">',
        		            'after_widget'  => '</div></div>'
                        ));

                    }

                }

            }

        }

        function oftt_footer_order() {

            $footer_order = get_theme_mod('footer_order');

?>
<div class="footer-widgets column-three grid-item">
<?php dynamic_sidebar( 'sidebar-3' ); ?>
</div>
<script type="text/javascript">
    (function () {
        var footerContent = [];
        if (typeof document.getElementsByClassName('footer-top')[0] !== 'undefined' && typeof document.getElementsByClassName('footer-widgets-outer-wrapper')[0] !== 'undefined') {
            document.getElementsByClassName('footer-nav-widgets-wrapper')[0].parentNode.insertBefore(document.getElementsByClassName('footer-nav-widgets-wrapper')[0].cloneNode(true), document.getElementsByClassName('footer-nav-widgets-wrapper')[0].nextSibling);
            document.getElementsByClassName('footer-top')[1].parentNode.removeChild(document.getElementsByClassName('footer-top')[1]);
            document.getElementsByClassName('footer-widgets-outer-wrapper')[0].parentNode.removeChild(document.getElementsByClassName('footer-widgets-outer-wrapper')[0]);
            footerContent[0] = document.getElementsByClassName('footer-nav-widgets-wrapper')[0];
            footerContent[1] = document.getElementsByClassName('footer-nav-widgets-wrapper')[1];
            footerContent[2] = document.getElementById('site-footer');
            footerContent[<?= $footer_order[0]; ?>].parentNode.insertBefore(footerContent[<?= $footer_order[0]; ?>], document.getElementById('site-content').nextSibling);
            footerContent[<?= $footer_order[1]; ?>].parentNode.insertBefore(footerContent[<?= $footer_order[1]; ?>], footerContent[<?= $footer_order[0]; ?>].nextSibling);
            footerContent[<?= $footer_order[2]; ?>].parentNode.insertBefore(footerContent[<?= $footer_order[2]; ?>], footerContent[<?= $footer_order[1]; ?>].nextSibling);
        } else if (typeof document.getElementsByClassName('footer-top')[0] === 'undefined' && typeof document.getElementsByClassName('footer-widgets-outer-wrapper')[0] === 'undefined') {
        } else if (typeof document.getElementsByClassName('footer-top')[0] === 'undefined') {
<?php

if (strpos($footer_order, '1') > strpos($footer_order, '2')) {

?>
            footerContent[0] = document.getElementsByClassName('footer-nav-widgets-wrapper')[0];
            footerContent[2] = document.getElementById('site-footer');
            footerContent[0].parentNode.insertBefore(footerContent[0], footerContent[2].nextSibling);
<?php

}

?>
        } else {
<?php

if (strpos($footer_order, '0') > strpos($footer_order, '2')) {

?>
            footerContent[0] = document.getElementsByClassName('footer-nav-widgets-wrapper')[0];
            footerContent[2] = document.getElementById('site-footer');
            footerContent[0].parentNode.insertBefore(footerContent[0], footerContent[2].nextSibling);
<?php

}

?>
        }
    }());
</script>
<?php

        }

        function oftt_get_footer_sidebars($index, $has_widgets) {

            if ($index == 'sidebar-2') {

		        if (is_active_sidebar('sidebar-3')) {

?>
<div class="footer-widgets column-three grid-item">
<?php dynamic_sidebar( 'sidebar-3' ); ?>
</div>
<script type="text/javascript">
    (function () {
        var sidebarWrapper = document.getElementsByClassName('footer-widgets-wrapper')[0],
        newSidebar = document.getElementsByClassName('footer-widgets-wrapper')[0].getElementsByClassName('column-three')[0];
        sidebarWrapper.appendChild(newSidebar);
    }());
</script>
<?php

                }

		        if (get_theme_mod('footer_sidebars') == 4 && is_active_sidebar('sidebar-4')) {

?>
<div class="footer-widgets column-four grid-item">
<?php dynamic_sidebar( 'sidebar-4' ); ?>
</div>
<script type="text/javascript">
    (function () {
        var sidebarWrapper = document.getElementsByClassName('footer-widgets-wrapper')[0],
        newSidebar = document.getElementsByClassName('footer-widgets-wrapper')[0].getElementsByClassName('column-four')[0];
        sidebarWrapper.appendChild(newSidebar);
    }());
</script>
<?php

                }

            }

        }

        function oftt_replace_powered_by_wordpress() {

?>
<script type="text/javascript">
    (function() {
        var el = document.getElementsByClassName('powered-by-wordpress')[0];
        var newEl = document.createElement('p');
        newEl.innerHTML = '<?= addslashes(get_theme_mod('replace_powered_by_wordpress')); ?>';
        newEl.classList.add("powered-by-wordpress");
        el.parentNode.replaceChild(newEl, el);
    })();
</script>
<?php

        }

        function oftt_privacy_link() {

            if (function_exists('get_the_privacy_policy_link')) {

                $privacy = get_the_privacy_policy_link('<p class="footer-privacy">', '</p>');

            }

            if ($privacy) {

                echo $privacy;

?>
<script type="text/javascript">
    (function () {
        document.getElementsByClassName('footer-copyright')[0].parentNode.insertBefore(document.getElementsByClassName('footer-privacy')[0], document.getElementsByClassName('footer-copyright')[0].nextSibling);
    }());
</script>
<?php

            }

        }

        function oftt_inject_slider_cover($slug, $name) {

            $slider_id = get_post_meta(get_the_ID(), 'oftt_cover_slider', true);

            if (!$slider_id) {

                $slider_id = get_theme_mod('slider_cover');

            }

            $slider_post_type = get_post_type($slider_id);

            if ($slider_post_type == 'ml-slider' && class_exists('MetaSliderPlugin')) {

?>
<div class="cover-slider">
<?= do_shortcode('[metaslider id="' . $slider_id . '"]'); ?>
</div>
<?php

            }

        }

        function oftt_theme_options_metabox_setup() {

            add_action('add_meta_boxes', array($this, 'oftt_add_theme_options_metabox'));

            if (ofttPremium::request_permission() == true) {

                add_action('save_post', array($this, 'oftt_save_theme_options_meta'), 10, 2);

            }

        }

        function oftt_add_theme_options_metabox() {

            add_meta_box('oftt_meta_box', __('Theme Options', 'options-for-twenty-twenty'), array($this, 'oftt_render_theme_options_metabox'), array('post', 'page'), 'side');

        }

        function oftt_render_theme_options_metabox($post) {

            $upgrade_link = '<a href="' . ofttCommon::upgrade_link() . '" title="' . __('Upgrade Options for Twenty Twenty', 'options-for-twenty-twenty') . '">' . __('Upgrade Options for Twenty Twenty', 'options-for-twenty-twenty') . '</a>';

            if (get_option('oftt_purchased') == false) {

                if (get_option('oftt_trial_date') && time() < (strtotime('+1 week', get_option('oftt_trial_date')))) {

                    $expiring_in = ceil(abs((strtotime('+1 week', get_option('oftt_trial_date'))) - time())/60/60/24);
                    $expiring_text = '<p><span class="attention">' . sprintf(_n('Options for Twenty Twenty plugin trial expires in less than %s day!', 'Options for Twenty Twenty plugin trial expires in less than %s days!', $expiring_in, 'options-for-twenty-twenty'), $expiring_in) . '</span>';
                    echo('<strong>' . $expiring_text . '</strong>' . ' ' . $upgrade_link . ' ' . __('to keep using all the options after that time.', 'options-for-twenty-twenty') . '</p>');

                } elseif (get_option('oftt_trial_date') && time() > (strtotime('+1 week', get_option('oftt_trial_date')))) {

                    $expiring_text = '<p><span class="attention">' . __('Options for Twenty Twenty Premium plugin free trial has expired', 'options-for-twenty-twenty') . '</span>';
                    echo('<strong>' . $expiring_text . '</strong>' . ' ' . $upgrade_link . ' ' . __('to use these options.', 'options-for-twenty-twenty') . '</p>');

                }

            }

            wp_nonce_field('options-for-twenty-twenty', 'oftt-meta-nonce');

            if (ofttPremium::request_permission() == true) {

?>
<input type="checkbox" name="oftt-hide-header" id="oftt-hide-header" value="1" <?php checked(get_post_meta($post->ID, 'oftt_hide_header', true), '1' ); ?> />
<label for="oftt-hide-header"><?= ((get_theme_mod('hide_all_headers') ? __('Show Header', 'options-for-twenty-twenty') : __('Hide Header', 'options-for-twenty-twenty'))); ?></label>
<br />
<input type="checkbox" name="oftt-hide-header-title" id="oftt-hide-header-title" value="1" <?php checked(get_post_meta($post->ID, 'oftt_hide_header_title', true), '1' ); ?> />
<label for="oftt-hide-header-title"><?= ((get_theme_mod('hide_all_header_titles') ? __('Show Header Title', 'options-for-twenty-twenty') : __('Hide Header Title', 'options-for-twenty-twenty'))); ?></label>
<br />
<input type="checkbox" name="oftt-hide-featured-image" id="oftt-hide-featured-image" value="1" <?php checked(get_post_meta($post->ID, 'oftt_hide_featured_image', true), '1' ); ?> />
<label for="oftt-hide-featured-image"><?= ((get_theme_mod('hide_all_featured_images') ? __('Show Featured Image', 'options-for-twenty-twenty') : __('Hide Featured Image', 'options-for-twenty-twenty'))); ?></label>
<br />
<input type="checkbox" name="oftt-show-sidebar" id="oftt-show-sidebar" value="1" <?php checked(get_post_meta($post->ID, 'oftt_show_sidebar', true), '1' ); ?> />
<label for="oftt-show-sidebar"><?= __('Show Sidebar', 'options-for-twenty-twenty'); ?></label>
<?php

                if ($post->post_type == 'page') {

                    $installed_sliders = array();

                    if (class_exists('MetaSliderPlugin')) {

                        $installed_sliders[] = 'ml-slider';

                    }

                    $sliders_array = array('' => 'No slider');

                    if (!empty($installed_sliders)) {

                        $available_sliders = get_posts(array(
                            'post_type' => $installed_sliders,
                            'posts_per_page' => -1,
                        ));

                        foreach ($available_sliders as $available_slider) {

                            $sliders_array[$available_slider->ID] = $available_slider->post_title;

                        }

                    }

?>
<br />
<label for="oftt-cover-slider"><?= __('Cover Template Slider:', 'options-for-twenty-twenty'); ?> (<?= sprintf(
                        wp_kses(__('Place a <a href="%s">MetaSlider</a> slider in the background of the Cover Template', 'options-for-twenty-twenty'), array('a' => array('href' => array()))),
                            esc_url(add_query_arg( array(
                                's' => 'ml-slider',
                                'tab' => 'search',
                                'type' => 'term'
                        ), admin_url('plugin-install.php')))
                    ); ?>)</label>
<select name="oftt-cover-slider" id="oftt-cover-slider" class="components-select-control__input">
<?php

                    foreach ($sliders_array as $key => $value) {

?>
<option value="<?= $key; ?>" <?php selected(get_post_meta($post->ID, 'oftt_cover_slider', true), $key ); ?>><?= esc_html($value); ?></option>
<?php

                    }

?>
</select>
<?php

                }

            } else {

?>

<p><?= $upgrade_link; ?> <?= __('to hide the header, header title or featured image, or to show the sidebar or to show a slider in the page Cover Template.', 'options-for-twenty-twenty'); ?></p>

<?php
            }

        }

        function oftt_save_theme_options_meta($post_id, $post) {

            if (!isset( $_POST['oftt-meta-nonce'] ) || !wp_verify_nonce($_POST['oftt-meta-nonce'], 'options-for-twenty-twenty')) {

                return;

            }

            $post_type = get_post_type_object( $post->post_type );

            if (!current_user_can($post_type->cap->edit_post, $post_id)) {

                return;

            }

            if (isset($_POST['oftt-hide-header']) && $_POST['oftt-hide-header'] == '1') {

                update_post_meta($post_id, 'oftt_hide_header', 1);

            } else {

                delete_post_meta($post_id, 'oftt_hide_header');

            }

            if (isset($_POST['oftt-hide-header-title']) && $_POST['oftt-hide-header-title'] == '1') {

                update_post_meta($post_id, 'oftt_hide_header_title', 1);

            } else {

                delete_post_meta($post_id, 'oftt_hide_header_title');

            }

            if (isset($_POST['oftt-hide-featured-image']) && $_POST['oftt-hide-featured-image'] == '1') {

                update_post_meta($post_id, 'oftt_hide_featured_image', 1);

            } else {

                delete_post_meta($post_id, 'oftt_hide_featured_image');

            }

            if (isset($_POST['oftt-show-sidebar']) && $_POST['oftt-show-sidebar'] == '1') {

                update_post_meta($post_id, 'oftt_show_sidebar', 1);

            } else {

                delete_post_meta($post_id, 'oftt_show_sidebar');

            }

            if (isset($_POST['oftt-cover-slider']) && absint($_POST['oftt-cover-slider'])) {

                update_post_meta($post_id, 'oftt_cover_slider', absint($_POST['oftt-cover-slider']));

            } else {

                delete_post_meta($post_id, 'oftt_cover_slider');

            }

        }

	}

    if (!class_exists('ofttPremium')) {

        require_once(dirname(__FILE__) . '/includes/class-oftt-premium.php');

    }

    function options_for_twenty_twenty_premium_init() {

        if (class_exists('options_for_twenty_twenty_class') && class_exists('ofttCommon')) {

            ofttPremium::start_trial();
            $options_for_twenty_twenty_premium_object = new options_for_twenty_twenty_premium_class();

        } else {

            add_action('admin_notices', 'ofttPremium::free_plugin_notice');

        }

    }

    add_action('plugins_loaded', 'options_for_twenty_twenty_premium_init');

}

?>
